; ----------------------------------------------------------
; simpleIrrlicht
; Irrlicht Wrapper
; Version 0.01 preAlpha
;
; Achtung: Funktionen und Variablen die mit "sirr_" beginnen 
; nicht anfassen!
; ----------------------------------------------------------


; ==========================================================
; Grafiktreiber
; ==========================================================
Const NULLDRIVER%		= 0
Const SOFTWARE%			= 1
Const BURNINGSVIDEO%	= 2
Const DIRECT3D8%		= 3 ; NOT LONGER SUPPORTED!
Const DIRECT3D9%		= 4
Const OPENGL%			= 5
Const DRIVERCOUNT%		= 6


; ==========================================================
; Tools
; ==========================================================
Function ConvCol#(value%)
	Return (1.0 / 255.0) * value
End Function

; ==========================================================
; Initialisierung
; ==========================================================
Global sirr_context% = sirr_Init() ; <== DON'T TOUCH!!

Function SetDriver(driverType% = OPENGL)
	If driverType > 0 And driverType < 7
		If(driverType <> 3)
			sirr_SetDriver(sirr_context, driverType)
		Else
			DebugLog "DirectX 8 is no longer supported in Irrlicht. Try another one."
		EndIf
	Else
		DebugLog "SetDriver: Kein gltiger Parameter"
	EndIf
End Function
Function VSync(mode% = False) : sirr_VSync(sirr_context, mode) : End Function
Function ClearBackbuffer(value% = True) : sirr_ClearBackbuffer(sirr_context, value) : End Function
Function ClearZBuffer(value% = True) : sirr_ClearZBuffer(sirr_context, value) : End Function
	
; ==========================================================
; Global
; ==========================================================
Function Graphics3D(width%, height%, depth% = 16, mode% = 0) : sirr_Graphics3D(sirr_context, width, height, depth, mode) : End Function
Function RenderWorld(tween% = 1.0) : sirr_RenderWorld(sirr_context, tween) : End Function
Function EndGraphics() : sirr_EndGraphics(sirr_context) : End Function
Function AmbientLight(red%, green%, blue%) : sirr_AmbientLight(sirr_context, ConvCol(red), ConvCol(green), ConvCol(blue)) : End Function
Function AntiAlias(value% = 0) : sirr_AntiAlias(sirr_context, value) : End Function
Function TrisRendered%() : Return sirr_TrisRendered(sirr_context) : End Function
Function GetFPS%() : Return sirr_GetFPS(sirr_context) : End Function
Function WireFrame(value%) : End Function
	
; ==========================================================
; Graphics
; ==========================================================
Function Flip() : End Function
Function SetBuffer() : End Function
Function BackBuffer() : End Function
Function ClsColor(red%, green%, blue%) : sirr_ClsColor(sirr_context, red, green, blue) : End Function
	
; ==========================================================
; System
; ==========================================================
Function AppTitle(title$) : sirr_AppTitle(sirr_context, title) : End Function
	
; ==========================================================
; Input
; ==========================================================
	Const LMOUSE% = 1
	Const RMOUSE% = 2
	Const MMOUSE% = 3
	
Function KeyDown%(key%) : Return sirr_KeyDown(sirr_context, key) : End Function
Function KeyHit%(key%) : Return sirr_KeyHit(sirr_context, key) : End Function
Function MouseDown%(button% = LMOUSE) : Return sirr_MouseDown(sirr_context, button) : End Function
Function MouseHit%(button% = LMOUSE) : Return sirr_MouseHit(sirr_context, button) : End Function
	
; ==========================================================
; Camera
; ==========================================================
	
Function CreateCamera%(parent% = 0) : Return sirr_CreateCamera(sirr_context, parent) : End Function
Function CreateFPSCamera%(parent% = 0) : Return sirr_CreateFPSCamera(sirr_context, parent) : End Function
Function CameraMoveSpeed(entity%, speed#) : sirr_CameraMoveSpeed(entity, speed) : End Function
Function CameraRotateSpeed(entity%, speed#) : sirr_CameraRotateSpeed(entity, speed) : End Function
Function CameraRange(entity%, near#, far#) : sirr_CameraRange(entity, near, far) : End Function
Function CameraZoom(entity%, zoom# = 1.0) : sirr_CameraZoom(entity, zoom) : End Function
Function SetFPSKeyMap(camera%, forward%, backward%, strafeLeft%, strafeRight%, jump%, crouch%)
	sirr_SetFPSKeyMap(camera%, forward, backward, strafeLeft, strafeRight, jump, crouch)
End Function
Function CameraClsColor(camera%, red%, green%, blue%) : sirr_CameraClsColor(camera, red, green, blue) : End Function

; ==========================================================
; Mesh
; ==========================================================
Function CreateCube%(parent% = 0) : Return sirr_CreateCube(sirr_context, parent) : End Function
Function CreateSphere%(segments% = 48, parent% = 0) : Return sirr_CreateSphere(sirr_context, segments, parent) : End Function
Function LoadMesh%(file$, parent% = 0) : Return sirr_LoadMesh(sirr_context, file$, parent) : End Function
Function LoadAnimMesh%(file$, parent% = 0) : Return sirr_LoadAnimMesh(sirr_context, file$, parent) : End Function
	
; ==========================================================
; Light
; ==========================================================
	Const LIGHT_DIRECTIONAL%	= 2
	Const LIGHT_POINT%			= 0
	Const LIGHT_SPOT%			= 1
	
Function CreateLight%(typ% = LIGHT_DIRECTIONAL, parent% = 0) : Return sirr_CreateLight(sirr_context, typ, parent) : End Function
Function LightRange(light%, range#) : sirr_LightRange(light%, range) : End Function
Function LightColor(light%, red#, green#, blue#) : sirr_LightColor(light%, ConvCol(red), ConvCol(green), ConvCol(blue)) : End Function
Function LightConeAngles(light%, inner_angle#, outer_angle#) : sirr_LightConeAngles(light, inner_angle, outer_angle) : End Function
	
; ==========================================================
; Entity Movement
; ==========================================================
Function PositionEntity(entity%, x#, y#, z#, glob% = 0) : sirr_PositionEntity(entity, x, y, z, glob) : End Function
Function RotateEntity(entity%, pitch#, yaw#, roll#, glob% = 0) : sirr_RotateEntity(entity, pitch, yaw, roll, glob) : End Function
Function TurnEntity(entity%, pitch#, yaw#, roll#, glob% = 0) : sirr_TurnEntity(entity, pitch, yaw, roll, glob) : End Function
Function MoveEntity(entity%, x#, y#, z#, glob% = 0) : sirr_MoveEntity(entity, x, y, z, glob) : End Function
Function PointEntity(entity%, target%, roll% = 0) : sirr_PointEntity(entity, target, roll) : End Function
Function ScaleEntity(entity%, x#, y#, z#, glob% = 0) : sirr_ScaleEntity(entity, x, y, z, glob) : End Function

; ==========================================================
; Entity Animation
; ==========================================================
Function ExtractAnimSeq%(entity%, first_frame%, last_frame%, anim_seq% = 0)
	Return sirr_ExtractAnimSeq(entity, first_frame, last_frame)
End Function

Function Animate(entity%, mode% = 1, speed# = 1, sequence% = 0, transition# = 0.0)
	sirr_Animate(entity, mode, speed, sequence, transition)
End Function

; ==========================================================
; Entity State
; ==========================================================
Function EntityX#(entity%, glob% = 0) : Return sirr_EntityX(entity, glob) : End Function
Function EntityY#(entity%, glob% = 0) : Return sirr_EntityY(entity, glob) : End Function
Function EntityZ#(entity%, glob% = 0) : Return sirr_EntityZ(entity, glob) : End Function
Function EntityRoll#(entity%, glob% = 0) : Return sirr_EntityRoll(entity, glob) : End Function
Function EntityYaw#(entity%, glob% = 0) : Return sirr_EntityYaw(entity, glob) : End Function
Function EntityPitch#(entity%, glob% = 0) : Return sirr_EntityPitch(entity, glob) : End Function
Function EntityClass$(entity%) : Return sirr_EntityClass(entity) : End Function
Function EntityName$(entity%) : Return sirr_EntityName(entity) : End Function
	
; ==========================================================
; Entity Control
; ==========================================================
Function FreeEntity(entity%) : sirr_FreeEntity(entity) : End Function
Function EntityTexture(entity%, texture%, frame% = 0, index% = 0) : sirr_EntityTexture(entity%, texture%, frame%, index%) : End Function
Function EntityAlpha(entity%, alpha#) : sirr_EntityAlpha(sirr_context, entity, Int(alpha * 255)) : End Function
Function EntityColor(entity%, red%, green%, blue%) : sirr_EntityColor(sirr_context, entity, red, green, blue) : End Function
Function EntityAmbientColor(entity%, red#, green#, blue#) : sirr_EntityAmbientColor(entity, red, green, blue) : End Function
Function EntitySpecularColor(entity%, red#, green#, blue#) : sirr_EntitySpecularColor(entity, red, green, blue) : End Function
Function EntityParent(entity%, parent%, glob% = 0) : sirr_EntityParent(entity, parent, glob) : End Function
Function GetParent%(entity%) : Return sirr_GetParent(entity) : End Function
Function ShowEntity(entity%) : sirr_ShowEntity(entity) : End Function
Function HideEntity(entity%) : sirr_HideEntity(entity) : End Function
Function CopyEntity%(entity%, parent% = 0) : Return sirr_CopyEntity(sirr_context, entity, parent) : End Function
Function NameEntity(entity%, name%) : sirr_NameEntity(entity, name) : End Function
Function EntityShininess(entity%, shininess#) : sirr_EntityShininess(entity%, shininess#) : End Function
	
;Function EntityShadow(entity%, value% = 1) : sirr_EntityShadow(entity%, value%) : End Function
	
; ==========================================================
; Pivot
; ==========================================================
Function CreatePivot%(parent% = 0) : Return sirr_CreatePivot(sirr_context, parent) : End Function

; ==========================================================
; Sprite
; ==========================================================

; ==========================================================
; MD2
; ==========================================================
Function LoadMD2%(file$, parent% = 0) : Return sirr_LoadAnimMesh(sirr_context, file$, parent) : End Function

; ==========================================================
; Terrain
; ==========================================================
	Const ETPS_9%	= 9		;! patch size of 9, at most, use 4 levels of detail with this patch size.
	Const ETPS_17%	= 17	;! patch size of 17, at most, use 5 levels of detail with this patch size.
	Const ETPS_33%	= 33	;! patch size of 33, at most, use 6 levels of detail with this patch size.
	Const ETPS_65%	= 65	;! patch size of 65, at most, use 7 levels of detail with this patch size.
	Const ETPS_129%	= 129	;! patch size of 129, at most, use 8 levels of detail with this patch size.
	
Function CreateTerrain%(patchSize% = ETPS_17, parent% = 0) : Return sirr_CreateTerrain(sirr_context, patchSize, parent) : End Function
	
; ==========================================================
; Texture
; ==========================================================
Function CreateTexture%(width%, height%, flags% = 1, frames% = 1) : Return sirr_CreateTexture(sirr_context, width, height, flags, frames) : End Function
Function LoadTexture%(file$, flags% = 1) : Return sirr_LoadTexture(sirr_context, file, flags) : End Function
Function FreeTexture(texture%) : sirr_FreeTexture(texture) : End Function
Function TextureWidth%(texture%) : Return sirr_TextureWidth(texture) : End Function
Function TextureHeight%(texture%) : Return sirr_TextureHeight(texture) : End Function
Function TextureName$(texture%) : Return sirr_TextureName(texture) : End Function
	
; ==========================================================
; Plane
; ==========================================================
Function CreatePlane%(segments% = 1, parent% = 0) : Return sirr_CreatePlane(sirr_context, segments, parent) : End Function
	
; ==========================================================
; Collisions
; ==========================================================
;Function EntityType(entity%, collision_type%, recursive% = 0) : sirr_EntityType(entity, collision_type, recursive) : End Function
	
; ==========================================================
; Brush
; ==========================================================
;Function CreateBrush%(red% = 255, green% = 255, blue% = 255, alpha% = 255) : Return sirr_CreateBrush(red, green, blue, alpha) : End Function
;Function PaintEntity(entity%, brush%) : sirr_PaintEntity(sirr_context, entity, brush) : End Function
;Function BrushAlpha(brush%, alpha#)
;	a% = 256 * alpha
;	sirr_BrushAlpha(brush, a)
;End Function

; ==========================================================
; Postprocessing
; ==========================================================
Function CreateScreenQuad%() : Return sirr_CreateScreenQuad(sirr_context) : End Function
;~IDEal Editor Parameters:
;~C#Blitz3D